@@ -18,16 +18,9 @@ import os
 
 
 # --- 初始化环境 ---
-if 1:
-    root_path = '..' + os.sep + 'templates'
-    root_path
-    html_path_ls = 1
-    os.path.exists(root_path)
-    os.path.exists('../templates')
-    os.path.exists('logs')
-    print(__file__)
+from .admin_env_init import run
+run()
 
-    1
 
 class IDAdmin(admin.ModelAdmin):
     """
