@@ -9,6 +9,10 @@ def f1():
     print('1')
 
 
+def version():
+    return '1.1.0'
+
+
 def conv_queryset_ls_to_serialzer_ls(qs: list):
     """
     queryset数据的序列化
@@ -70,21 +74,3 @@ def add_space_prefix(text, n, more=True, prefix='\u3000'):
         ret = prefix * (n - len(text)) + text
     return ret
 
-
-def conv_df_to_serializer_data(df: pd.DataFrame, add_index=False) -> list:
-    assert isinstance(df, pd.DataFrame), 'df的类型必须是DataFrame!'
-    ret_ls = []
-    for index, row in df.iterrows():
-        k = row.index.tolist()
-        v = row.values.tolist()
-        data = dict(zip(k, v))
-
-        if add_index:
-            # 将df的index作为dc_ls的key
-            data = {
-                'name': index,
-                'value': data
-            }
-
-        ret_ls.append(data)
-    return ret_ls
